OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "מצבים אחרונים",
    "In a meeting" : "בפגישה",
    "Commuting" : "בדרכים",
    "Out sick" : "בחופשת מחלה",
    "Vacationing" : "בחופש",
    "Working remotely" : "בעבודה מרחוק",
    "User status" : "מצב משתמש",
    "Clear status after" : "לפנות את המצב לאחר",
    "What is your status?" : "מה המצב שלך?",
    "Set status" : "הגדרת מצב",
    "Online status" : "מצב מקוון",
    "Status message" : "הודעת מצב",
    "Clear status message" : "פינוי הודעת המצב",
    "Set status message" : "הגדרת הודעת מצב",
    "There was an error saving the status" : "אירעה שגיאה בשמירת המצב",
    "There was an error clearing the status" : "אירעה שגיאה בפינוי המצב",
    "No recent status changes" : "אין שינויים אחרונים למצב",
    "Away" : "לא פה",
    "Do not disturb" : "לא להפריע",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "לא לפנות",
    "Today" : "היום",
    "This week" : "השבוע",
    "Online" : "מקוון",
    "Invisible" : "נסתרת",
    "Offline" : "בלתי מקוון",
    "There was an error saving the new status" : "אירעה שגיאה בשמירת המצב החדש",
    "30 minutes" : "30 דקות",
    "1 hour" : "שעה",
    "4 hours" : "4 שעות",
    "Mute all notifications" : "השתקת כל ההתראות",
    "Appear offline" : "להופיע במצב בלתי מקוון",
    "Clear status message after" : "מחיקת הודעת מצב לאחר",
    "What's your status?" : "מה המצב שלך?"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
